@@ -2,7 +2,7 @@ import logging
 
 from typing import Optional, Dict, Any, Union, Iterator  # noqa: F401
 
-from databuilder.models.dashboard_metadata import DashboardMetadata
+from databuilder.models.dashboard.dashboard_metadata import DashboardMetadata
 from databuilder.models.neo4j_csv_serde import (
     Neo4jCsvSerializable, NODE_LABEL, NODE_KEY, RELATION_START_KEY, RELATION_END_KEY, RELATION_START_LABEL,
     RELATION_END_LABEL, RELATION_TYPE, RELATION_REVERSE_TYPE)
@@ -17,8 +17,8 @@ class DashboardExecution(Neo4jCsvSerializable):
     DASHBOARD_EXECUTION_LABEL = 'Execution'
     DASHBOARD_EXECUTION_KEY_FORMAT = '{product}_dashboard://{cluster}.{dashboard_group_id}/' \
                                      '{dashboard_id}/execution/{execution_id}'
-    DASHBOARD_EXECUTION_RELATION_TYPE = 'LAST_EXECUTED'
-    EXECUTION_DASHBOARD_RELATION_TYPE = 'LAST_EXECUTION_OF'
+    DASHBOARD_EXECUTION_RELATION_TYPE = 'EXECUTED'
+    EXECUTION_DASHBOARD_RELATION_TYPE = 'EXECUTION_OF'
 
     LAST_EXECUTION_ID = '_last_execution'
     LAST_SUCCESSFUL_EXECUTION_ID = '_last_successful_execution'
@@ -55,7 +55,7 @@ class DashboardExecution(Neo4jCsvSerializable):
         yield {
             NODE_LABEL: DashboardExecution.DASHBOARD_EXECUTION_LABEL,
             NODE_KEY: self._get_last_execution_node_key(),
-            'time_stamp': self._execution_timestamp,
+            'timestamp': self._execution_timestamp,
             'state': self._execution_state
         }
 
